# coding: utf-8
import subprocess
from os.path import isdir, isfile, join
from os import makedirs, listdir, rename, unlink
from shutil import rmtree
from zipfile import ZipFile
from json import dumps
import traceback
from pyeole.lock import is_locked

from .action import describe as _describe, submit as _submit, _get_tiramisu_informations

CMD_PROCESSFILE = "/usr/share/eole/sbin/import-aaf.py"

def _send_error_message(msg):
    return _send_message(u"Erreur {}".format(msg), 'error')


def _send_message(msg, level='info'):
    return dumps({'message': {'type': level, 'text': msg}})


def processfile(filename, level, delete=False, **kwargs):
    """
    :param filename: fullpath of the archive to unzip
    :param level: type of import ('complète' or 'delta')
    :param delete: if True, remove the import file after successfull process
    """
    try:
        ret = subprocess.run([CMD_PROCESSFILE, filename, level, str(delete)], check=True)
    except subprocess.CalledProcessError as err:
        ret = err
    ret = ret.returncode
    messages = {0: 'Importation effectuée',
                1: "Paramètre invalide : type d'import",
                2: "Impossible de lancer l'import complet",
                3: "Impossible de trouver le fichier à décompresser",
                4: "La base est vide, impossible de réaliser une importation de type delta",
                5: "Impossible de vérifier si la base est vide",
                6: "Erreur à la création du répertoire de travail",
                7: "Erreur à la décompression des fichiers",
                8: "Erreur à l'importation des comptes dans la base" }
    return _send_message(messages[ret])


def describe(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("un import AAF est en cours")
    return _describe(*args, **kwargs)


def submit(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("une action AAF est en cours")
    dico, values, config = _get_tiramisu_informations(args)
    upload_folder = config.creole.ead3.ead3_upload_path
    kwargs['dico'] = (dico, values, config)
    if dico['importaaf.aaf.aaf_filename'] == "Aucun fichier téléversé depuis l'action 'Gérer les fichiers'":
        return _send_error_message('aucun fichier selectionné')
    filename = join(upload_folder, dico['importaaf.aaf.aaf_filename'])
    return processfile(filename, dico['importaaf.aaf.aaf_type'], delete=True)


__CUSTOM_MODULES__ = ('processfile',)
