# coding: utf-8
from json import dumps
import traceback
from pyeole.lock import is_locked
import subprocess

from logging import getLogger
aaflog = getLogger("AAF")

from .action import describe as _describe, submit as _submit

CMD_PROCESSFILE = "/usr/share/eole/sbin/import-ad.py"


def _send_error_message(msg):
    return _send_message(u"Erreur {}".format(msg), remove_lock, 'error')


def _send_message(msg, level='info'):
    return dumps({'message': {'type': level, 'text': msg}})


def launch(**kwargs):
    messages = {0: {'msg': 'Importation effectuée', 'level': 'info'},
                1: {'msg': 'Erreur indéfinie : {}', 'level': 'error'},
                2: {'msg': 'Impossible de lancer l’import complet : {}', 'level': 'error'},
                3: {'msg': 'Erreur à l’importation des comptes dans l’annuaire : {}', 'level': 'error'}
                }
    try:
        ret = subprocess.run([CMD_PROCESSFILE], check=True)
        returncode = ret.returncode
        message = 'Importation effectuée'
        level = 'info'
    except subprocess.CalledProcessError as err:
        returncode = err.returncode
        message = messages[returncode]['msg'].format(err)
        level = messages[returncode]['level']
    return _send_message(message, level=level)


def describe(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("un import AAF est en cours")
    return _describe(*args, **kwargs)


def submit(*args, **kwargs):
    if is_locked(name='importaaf', level='system'):
        return _send_error_message("une action AAF est en cours")
    return launch()
__CUSTOM_MODULES__ = ('launch',)
